pub enum FormatError {
ReceivedTextForBinary,
ReceivedBinaryForText,
CantEncodeBinaryAsText,
}Expand description
Represents formatting errors.
Variants
ReceivedTextForBinary
Received text for a binary format, e.g. someone sending text on a WebSocket that is using a binary serialization format, like Cbor.
ReceivedBinaryForText
Received binary for a text format, e.g. someone sending binary on a WebSocket that is using a text serialization format, like Json.
CantEncodeBinaryAsText
Trying to encode a binary format as text“, e.g., trying to store a Cbor encoded value in a String.